@@ -3,27 +3,25 @@
 from autobahn.asyncio.component import Component, run
 from autobahn.wamp.types import RegisterOptions
 from autobahn.wamp.exception import ApplicationError
-import asyncio
 
 
-@asyncio.coroutine
-def main(reactor, session):
+async def main(reactor, session):
     print("Client session={}".format(session))
 
     try:
-        res = yield from session.register(lambda: None, "com.foo.private")
+        res = await session.register(lambda: None, "com.foo.private")
         print("\n\nregistering 'com.foo.private' should have failed\n\n")
     except ApplicationError as e:
         print("registering 'com.foo.private' failed as expected: {}".format(e.error))
 
-    res = yield from session.register(
+    res = await session.register(
         lambda: None, "should.work",
         options=RegisterOptions(match='exact'),
     )
     print("registered 'should.work' with id {}".format(res.id))
 
     try:
-        res = yield from session.register(
+        res = await session.register(
             lambda: None, "prefix.fail.",
             options=RegisterOptions(match='prefix'),
         )
@@ -32,7 +30,7 @@ def main(reactor, session):
         print("prefix-match 'prefix.fail.' failed as expected: {}".format(e.error))
 
     print("calling 'example.foo'")
-    res = yield from session.call("example.foo")
+    res = await session.call("example.foo")
     print("example.foo() = {}".format(res))
 
     print("done")
